/*****************************************************************************
 *   See the file COPYING for full copying permissions.                      *
 *                                                                           *
 *   This program is free software: you can redistribute it and/or modify    *
 *   it under the terms of the GNU General Public License as published by    *
 *   the Free Software Foundation, either version 2 of the License, or       *
 *   (at your option) any later version.                                     *
 *                                                                           *
 *   This program is distributed in the hope that it will be useful,         *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the            *
 *   GNU General Public License for more details.                            *
 *                                                                           *
 *   You should have received a copy of the GNU General Public License       *
 *   along with this program. If not, see <http://www.gnu.org/licenses/>.    *
 *****************************************************************************/
/*!
 * \file
 *
 * \brief Dumux-equivalent for GRUWA (1p-stationary, finite volumes)
 */
#ifndef DUMUX_LECTURE_MHS_GROUNDWATER_PROPERTIES_HH
#define DUMUX_LECTURE_MHS_GROUNDWATER_PROPERTIES_HH

#include <cmath>

#include <dune/grid/yaspgrid.hh>

#include <dumux/porousmediumflow/1p/sequential/diffusion/cellcentered/pressureproperties.hh>
#include <dumux/material/fluidsystems/1pliquid.hh>

#include <lecture/mm/buckleyleverett/pseudoh2o.hh>
#include "groundwaterspatialparams.hh"
#include "groundwaterproblem.hh"


namespace Dumux::Properties {

// Create new type tags
namespace TTag {
struct GroundwaterProblemTypeTag { using InheritsFrom = std::tuple<FVPressureOneP>; };
} // end namespace TTag

// Set the grid type
template<class TypeTag>
struct Grid<TypeTag, TTag::GroundwaterProblemTypeTag> { using type = Dune::YaspGrid<2>; };

// Set the fluid system
template<class TypeTag>
struct FluidSystem<TypeTag, TTag::GroundwaterProblemTypeTag>
{
    using Scalar = GetPropType<TypeTag, Properties::Scalar>;
    using type = FluidSystems::OnePLiquid<Scalar, PseudoH2O<Scalar> >;
};

// Set the spatial parameters
template<class TypeTag>
struct SpatialParams<TypeTag, TTag::GroundwaterProblemTypeTag> { using type = Dumux::GroundwaterSpatialParams<TypeTag>; };

//Set the problem
template<class TypeTag>
struct Problem<TypeTag, TTag::GroundwaterProblemTypeTag> { using type = Dumux::GroundwaterProblem<TypeTag>; };

} // end namespace Dumux::Properties

#endif
