// -*- mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
// vi: set et ts=4 sw=4 sts=4:
/*****************************************************************************
 *   See the file COPYING for full copying permissions.                      *
 *                                                                           *
 *   This program is free software: you can redistribute it and/or modify    *
 *   it under the terms of the GNU General Public License as published by    *
 *   the Free Software Foundation, either version 2 of the License, or       *
 *   (at your option) any later version.                                     *
 *                                                                           *
 *   This program is distributed in the hope that it will be useful,         *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of          *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the            *
 *   GNU General Public License for more details.                            *
 *                                                                           *
 *   You should have received a copy of the GNU General Public License       *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>.   *
 *****************************************************************************/
/*!
 * \file
 *
 * \brief Properties file for water management in PEM fuel cells.
 */
#ifndef DUMUX_FUELCELL_LECTURE_PROPERTIES_HH
#define DUMUX_FUELCELL_LECTURE_PROPERTIES_HH

#include <dune/grid/yaspgrid.hh>

#include <dumux/porousmediumflow/2pnc/model.hh>
#include <dumux/material/fluidsystems/h2on2o2.hh>
#include <dumux/discretization/box.hh>

#include "fuelcellspatialparams.hh"

#include "fuelcellproblem.hh"

namespace Dumux::Properties {

#if ISOTHERMAL
// Create new type tags
namespace TTag {
struct FuelCellLectureProblem { using InheritsFrom = std::tuple<FuelCellLectureSpatialParamsTypeTag, TwoPNC, BoxModel>; };
} // end namespace TTag
#else
namespace TTag {
struct FuelCellLectureProblem { using InheritsFrom = std::tuple<FuelCellLectureSpatialParams, TwoPNCNI, BoxModel>; };
} // end namespace TTag
#endif

// Set the grid type
template<class TypeTag>
struct Grid<TypeTag, TTag::FuelCellLectureProblem> { using type = Dune::YaspGrid<2>; };

// Set the problem property
template<class TypeTag>
struct Problem<TypeTag, TTag::FuelCellLectureProblem> { using type = FuelCellLectureProblem<TypeTag>; };

// Set the primary variable combination for the 2pnc model
template<class TypeTag>
struct Formulation<TypeTag, TTag::FuelCellLectureProblem>
{
    static constexpr auto value = TwoPFormulation::p1s0;
};

// Set fluid configuration
template<class TypeTag>
struct FluidSystem<TypeTag, TTag::FuelCellLectureProblem>
{
private:
    using Scalar = GetPropType<TypeTag, Properties::Scalar>;
public:
    using type = FluidSystems::H2ON2O2<Scalar>;
};

// Define which component balance equation gets replaced by total balance {0,1,2,..,numComponents(none)}
template<class TypeTag>
struct ReplaceCompEqIdx<TypeTag, TTag::FuelCellLectureProblem> { static constexpr int value = 3; };

} // end namespace Dumux::Properties

#endif
